fedex.services.ship_service.FedexProcessShipmentRequest

Package fedex :: Package services :: Module ship_service :: Class FedexProcessShipmentRequest |
[hide private]
[frames] | no frames]

# Class FedexProcessShipmentRequest

source code

This class allows you to process (create) a new FedEx shipment. You will need to populate the data structures in self.RequestedShipment, then send the request. Label printing is supported and very configurable, returning an ASCII representation with the response as well.

Instance Methods | [hide private]
__init__(self, config_obj, *args, **kwargs) The optional keyword args detailed on FedexBaseService apply here as well. | source code
_prepare_wsdl_objects(self) This is the data that will be used to create your shipment. | source code
send_validation_request(self) This is very similar to just sending the shipment via the typical send_request() function, but this doesn't create a shipment. | source code
_assemble_and_send_validation_request(self) Fires off the Fedex shipment validation request. | source code
_assemble_and_send_request(self) Fires off the Fedex request. | source code
add_package(self, package_item) Adds a package to the ship request. | source code
Inherited from `base_service.FedexBaseService`: `create_wsdl_object_of_type`, `send_request` Inherited from `base_service.FedexBaseService` (private): `_check_response_for_request_errors` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Instance Variables | [hide private]
| RequestedShipment Holds the RequestedShipment WSDL object.
Inherited from `base_service.FedexBaseService`: `ClientDetail`, `TransactionDetail`, `VersionId`, `WebAuthenticationDetail`, `config_obj`, `logger`, `response`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, config_obj, *args, **kwargs) (Constructor) | source code
The optional keyword args detailed on FedexBaseService apply here as well. Parameters: `config_obj` (FedexConfig) - A valid FedexConfig object. Overrides: object.__init__

### _prepare_wsdl_objects(self) | source code
This is the data that will be used to create your shipment. Create the data structure and get it ready for the WSDL request.

### send_validation_request(self) | source code
This is very similar to just sending the shipment via the typical send_request() function, but this doesn't create a shipment. It is used to make sure "good" values are given by the user or the application using the library.

### _assemble_and_send_validation_request(self) | source code
Fires off the Fedex shipment validation request. Warning: NEVER CALL THIS METHOD DIRECTLY. CALL send_validation_request(), WHICH RESIDES ON FedexBaseService AND IS INHERITED.

### _assemble_and_send_request(self) | source code
Fires off the Fedex request. Warning: NEVER CALL THIS METHOD DIRECTLY. CALL send_request(), WHICH RESIDES ON FedexBaseService AND IS INHERITED.

### add_package(self, package_item) | source code
Adds a package to the ship request. Parameters: `package_item` (WSDL object, type of RequestedPackageLineItem WSDL object.) - A RequestedPackageLineItem, created by calling create_wsdl_object_of_type('RequestedPackageLineItem') on this ShipmentRequest object. See examples/create_shipment.py for more details.